/******************************************************************************/
/* AGENT2B                                                                    */
/*                                                                            */
/* Pedidos                                                                    */
/******************************************************************************/
/*                                                                            */
/* Nome: GERA_SUGESTAO_COMPRA                                                 */
/*                                                                            */
/* Criao:                                                                   */
/*    16/12/2004 - Welbert                                                    */
/*                                                                            */
/*  @C:\Win_V4\Sql\End_Conv\Oracle\2856_PEDSTPO.SQL                           */
/*                                                                            */
/*  PROCEDURES                                                                */
/*     - GERA_SOLICMP                                                         */
/*     - GERA_SUGESTAO_COMPRA                                                 */
/******************************************************************************/
/*  P_IDTPRELSUG  - TIPO DE RELATRIO                                         */
/*    '1' SUGESTO DE CAMPRAS                                                 */
/*    '2' PEDIDO PENDENTE                                                     */
/*                                                                            */
/*  P_IDGERASOLCMP - GERA SOLICITAO DE COMPRAS: 'S' SIM - 'N' NO           */
/*                                                                            */
/*  P_IDMENSSOLI - INDICA SE A SOLICITAO FOI GERADA                         */
/*    '0' PARMETRO PARA GERAR A SOLICITAO FOI PASSADO COM 'N'              */
/*    '1' SOLICITAO DE COMPRAS GERADA COM TODOS OS PRODUTOS DO FORNECEDOR   */
/*    '2' SOLICITAO DE COMPRAS GERADA SEM TODOS OS PRODUTOS DO FORNECEDOR   */
/*          J EXISTE SOLICITAO PARA ALGUMS PRODUTOS PARA MESMA FILIAL E DATA DE ENTREGA. */
/*    '3' SOLICITAO DE COMPRAS NO FOI GERADA.                              */
/******************************************************************************/
/******************************************************************************/
/********************** GERA SOLICITAO DE COMPRAS ***************************/
CREATE OR REPLACE PROCEDURE GERA_SOLICMP(P_CDFILSOLI    IN SOLICITA.CDFILSOLI%TYPE,
                                         P_CDFILLAN     IN SOLICITA.CDFILLANCA%TYPE,
                                         P_NRSOLICMP    IN SOLICITA.NRSOLICMP%TYPE,
                                         P_DTENTSOLICMP IN DATE,
                                         P_DTSOLCMP     IN DATE,
                                         P_NRLISTA      IN LISTA.NRLISTA%TYPE,
                                         P_NRSUGCOMPRA  IN VARCHAR2,
                                         P_IDTPRELSUG   IN VARCHAR2,
                                         P_IDMENSSOLI  OUT VARCHAR2)
AS
   V_GEROU_SOLI  NUMBER;
BEGIN
   V_GEROU_SOLI := 0;
   P_IDMENSSOLI := '1';
   FOR C_PRF IN
     (SELECT DISTINCT PR.CDPRODUTO
      FROM PRODUTO PR
      WHERE (PR.CDPRODESTO IS NOT NULL)
        AND EXISTS
              (SELECT PF.CDPRODUTO
               FROM PRODUTO P, PRODFORN PF, LISTA LI
               WHERE (LI.NRLISTA    = P_NRLISTA)
                 AND (PF.CDFORNECED = LI.CDLISTA)
                 AND (PF.CDPRODUTO  = P.CDPRODUTO)
                 AND (PR.CDARVPROD LIKE P.CDARVPROD||'%'))
      ) LOOP

      IF V_GEROU_SOLI = 0 THEN
         INSERT INTO SOLICITA
            (CDFILSOLI,  CDFILLANCA, NRSOLICMP,
             DTSOLCMP,   IDTIPLAN,  CDFILCENT)
         VALUES
            (P_CDFILSOLI, P_CDFILLAN, P_NRSOLICMP,
             P_DTSOLCMP,  'A',        P_CDFILLAN);

         V_GEROU_SOLI := 1;
      END IF;

      INSERT INTO ITEMSOLI
         (CDFILSOLI, CDFILLAN, NRSOLICMP,
          CDPRODUTO, DTPROGENTR, QTSOLIPROD)
      VALUES
         (P_CDFILSOLI,     P_CDFILLAN,     P_NRSOLICMP,
          C_PRF.CDPRODUTO, P_DTENTSOLICMP, 0);
   END LOOP;

   IF V_GEROU_SOLI = 1 THEN
      IF P_IDTPRELSUG = '1' THEN
         FOR C_SUG IN
           (SELECT
               CDPROSUGCOMP, QTCOMPRA
            FROM TRAB_SUGCOMPRA
            WHERE CDFILSUGCOMP = P_CDFILSOLI
              AND NRSUGCOMPRA  = P_NRSUGCOMPRA
              AND QTCOMPRA     > 0
            ORDER BY CDPROSUGCOMP
            ) LOOP

            UPDATE ITEMSOLI
            SET QTSOLIPROD = C_SUG.QTCOMPRA
            WHERE CDFILSOLI  = P_CDFILSOLI
              AND CDFILLAN   = P_CDFILLAN
              AND NRSOLICMP  = P_NRSOLICMP
              AND CDPRODUTO  = C_SUG.CDPROSUGCOMP
              AND DTPROGENTR = P_DTENTSOLICMP;
         END LOOP;
      ELSE
         FOR C_SUG IN
           (SELECT
               CDPROSUGCOMP, QTESTOQSGCMP, SUM(QTCOMPRA) QTCOMPRA
            FROM TRAB_SUGCOMPRA
            WHERE CDFILSUGCOMP = P_CDFILSOLI
              AND NRSUGCOMPRA  = P_NRSUGCOMPRA
              AND QTSAIDAATUAL > 0
            GROUP BY CDPROSUGCOMP, QTESTOQSGCMP
            ) LOOP

            UPDATE ITEMSOLI
            SET QTSOLIPROD = ABS(NVL(C_SUG.QTESTOQSGCMP, 0) - NVL(C_SUG.QTCOMPRA, 0))
            WHERE CDFILSOLI  = P_CDFILSOLI
              AND CDFILLAN   = P_CDFILLAN
              AND NRSOLICMP  = P_NRSOLICMP
              AND CDPRODUTO  = C_SUG.CDPROSUGCOMP
              AND DTPROGENTR = P_DTENTSOLICMP;
         END LOOP;
      END IF;
   ELSE
      P_IDMENSSOLI := '3';
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('GERA_SOLICMP','5.01.014'); END;
/

